"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var mediafilepicker_common_1 = require("./mediafilepicker.common");
var utils = require("tns-core-modules/utils/utils");
var fs = require("tns-core-modules/file-system/file-system");
var MediafilepickerDeligate = (function (_super) {
    __extends(MediafilepickerDeligate, _super);
    function MediafilepickerDeligate() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MediafilepickerDeligate.initWithOwner = function (owner) {
        var deligate = MediafilepickerDeligate.new();
        deligate._owner = owner;
        return deligate;
    };
    MediafilepickerDeligate.prototype.assetsPickerControllerDidFinishPickingAssets = function (picker, assetArray) {
        picker.dismissViewControllerAnimatedCompletion(true, null);
        this._owner.get().getFiles(assetArray);
    };
    return MediafilepickerDeligate;
}(NSObject));
MediafilepickerDeligate.ObjCProtocols = [GMImagePickerControllerDelegate];
exports.MediafilepickerDeligate = MediafilepickerDeligate;
var Mediafilepicker = (function (_super) {
    __extends(Mediafilepicker, _super);
    function Mediafilepicker() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.output = "";
        return _this;
    }
    Mediafilepicker.prototype.startFilePicker = function (params) {
        var folder = fs.knownFolders.documents();
        folder.getFolder("filepicker");
        var options = params.ios;
        var picker = GMImagePickerController.alloc().init();
        picker.delegate = MediafilepickerDeligate.initWithOwner(new WeakRef(this));
        options.allowsMultipleSelection ? picker.allowsMultipleSelection = true : picker.allowsMultipleSelection = false;
        options.displaySelectionInfoToolbar ? picker.displaySelectionInfoToolbar = true : picker.displaySelectionInfoToolbar = false;
        options.displayAlbumsNumberOfAssets ? picker.displayAlbumsNumberOfAssets = true : picker.displayAlbumsNumberOfAssets = false;
        options.confirmSingleSelection ? picker.confirmSingleSelection = true : picker.confirmSingleSelection = false;
        options.showCameraButton ? picker.showCameraButton = true : picker.showCameraButton = false;
        options.autoSelectCameraImages ? picker.autoSelectCameraImages = true : picker.autoSelectCameraImages = false;
        if (options.title) {
            picker.title = options.title;
        }
        if (options.mediaTypes == "image") {
            picker.mediaTypes = [(PHAssetMediaTypeImage)];
        }
        else if (options.mediaTypes == "video") {
            picker.mediaTypes = [(PHAssetMediaTypeVideo)];
        }
        if (picker.customNavigationBarPrompt) {
            picker.customNavigationBarPrompt = picker.customNavigationBarPrompt;
        }
        if (options.confirmSingleSelectionPrompt) {
            picker.confirmSingleSelectionPrompt = options.confirmSingleSelectionPrompt;
        }
        if (options.colsInPortrait) {
            picker.colsInPortrait = options.colsInPortrait;
        }
        if (options.colsInLandscape) {
            picker.colsInLandscape = options.colsInLandscape;
        }
        if (options.minimumInteritemSpacing) {
            picker.minimumInteritemSpacing = options.minimumInteritemSpacing;
        }
        var app = utils.ios.getter(UIApplication, UIApplication.sharedApplication);
        app.keyWindow.rootViewController.presentViewControllerAnimatedCompletion(picker, true, null);
    };
    Mediafilepicker.prototype.getFiles = function (assetArray) {
        var t = this;
        t.handleJob(assetArray).then(function (res) {
            setTimeout(function () {
                t.output = t.output.replace(/,+$/, '');
                t.notify({
                    eventName: "getFiles",
                    object: t,
                    files: t.output
                });
            }, 200);
        }).catch(function (er) {
            t.notify({
                eventName: "error",
                object: t,
                msg: er
            });
        });
    };
    Mediafilepicker.prototype.handleJob = function (assetArray) {
        var t = this;
        var edit = PHContentEditingInputRequestOptions.alloc().init();
        return new Promise(function (resolve, reject) {
            var _loop_1 = function (i) {
                var data = assetArray[i];
                var rawData = assetArray[i];
                if (data.mediaType == 1) {
                    var _uriRequestOptions = PHImageRequestOptions.alloc().init();
                    _uriRequestOptions.synchronous = true;
                    PHImageManager.defaultManager().requestImageDataForAssetOptionsResultHandler(data, _uriRequestOptions, function (data, uti, orientation, info) {
                        var uri = info.objectForKey("PHImageFileURLKey");
                        var newUri = uri.toString();
                        var fileName = newUri.replace(/^.*[\\\/]/, '');
                        t.copyImageFiles(rawData, fileName);
                    });
                }
                else if (data.mediaType == 2) {
                    var uriVideoRequestOptions = PHVideoRequestOptions.alloc().init();
                    PHImageManager.defaultManager().requestAVAssetForVideoOptionsResultHandler(data, uriVideoRequestOptions, function (data, audioMix, info) {
                        var urlAsset = data;
                        var uri = urlAsset.URL;
                        var newUri = uri.toString();
                        var fileName = newUri.replace(/^.*[\\\/]/, '');
                        t.copyVideoFiles(urlAsset.URL, fileName);
                    });
                }
            };
            for (var i = 0; i < assetArray.count; i++) {
                _loop_1(i);
            }
            resolve(t.output);
        });
    };
    Mediafilepicker.prototype.copyImageFiles = function (rawData, fileName) {
        var t = this;
        return new Promise(function (resolve, reject) {
            var docuPath = fs.knownFolders.documents();
            var targetImgeURL = docuPath.path + "/filepicker/" + fileName;
            var phManager = PHImageManager.defaultManager();
            var options = PHImageRequestOptions.alloc().init();
            options.synchronous = true;
            phManager.requestImageDataForAssetOptionsResultHandler(rawData, options, function (imageData, dataUTI, orientation, info) {
                var newData = imageData;
                if (newData) {
                    try {
                        newData.writeToFileAtomically(targetImgeURL, true);
                        t.output = targetImgeURL.toString() + "," + t.output;
                        resolve(targetImgeURL);
                    }
                    catch (e) {
                        reject(e);
                    }
                }
            });
        });
    };
    Mediafilepicker.prototype.copyVideoFiles = function (url, fileName) {
        var t = this;
        return new Promise(function (resolve, reject) {
            var docuPath = fs.knownFolders.documents();
            var targetURL = NSURL.fileURLWithPath(docuPath.path + "/filepicker/" + fileName);
            if (fs.File.exists(docuPath.path + "/filepicker/" + fileName)) {
                docuPath.getFile("filepicker/" + fileName).remove();
            }
            try {
                var write_1 = NSFileManager.defaultManager.copyItemAtURLToURLError(url, targetURL);
                if (write_1) {
                    t.output = targetURL.toString() + "," + t.output;
                    resolve(t.output);
                }
                else {
                    reject("Not copied");
                }
            }
            catch (e) {
                reject(e);
            }
        });
    };
    return Mediafilepicker;
}(mediafilepicker_common_1.Common));
exports.Mediafilepicker = Mediafilepicker;
//# sourceMappingURL=mediafilepicker.ios.js.map